==> dnet-hadoop-service-1.0.5-sources.jar: eu/dnetlib/data/hadoop/action/SequenceFileFeeder.java <==
package eu.dnetlib.data.hadoop.action;

import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.SequenceFile;
import org.apache.hadoop.io.Text;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Required;

import eu.dnetlib.data.hadoop.config.ClusterName;
import eu.dnetlib.data.hadoop.config.ConfigurationEnumerator;
import eu.dnetlib.data.hadoop.hdfs.SequenceFileWriterFactory;
import eu.dnetlib.enabling.resultset.client.ResultSetClientFactory;

public class SequenceFileFeeder {
	
	private static final Log log = LogFactory.getLog(SequenceFileFeeder.class); // NOPMD by marko on 11/24/08 5:02 PM
	
	private ResultSetClientFactory resultSetClientFactory;
	
	@Autowired
	protected ConfigurationEnumerator configurationEnumerator;
	
	@Autowired
	protected SequenceFileWriterFactory sequenceFileWriterFactory;
	
	public void feed(final String epr, final ClusterName clusterName, final String path, final ImportEprActionCallback callback) {
	
		final Thread feederThread = new Thread(new Runnable() {
			
			@Override
			public void run() {
				try {
					callback.done(doWrite(epr, clusterName, path));
				} catch (Throwable e) {
					callback.failed(e);
				}
			}

			private int doWrite(final String epr, final ClusterName clusterName, final String path) throws IOException {
				final SequenceFile.Writer writer = sequenceFileWriterFactory.getSequenceFileWriter(Text.class, Text.class, getConf(clusterName), new Path(path));
				
				final Text idText = new Text();
				final Text bodyText = new Text();
				
				int count = 0;
				
				for (String record : getResultSetClientFactory().getClient(epr)) {
					idText.set(String.valueOf(count++));
					bodyText.set(record);
					writer.append(idText, bodyText);
				}
				writer.close();

				log.info("written " + count + " records in sequence file: " + path.toString());
				return count;
			}	
		});
		
		feederThread.start();
	}

	protected Configuration getConf(ClusterName clusterName) {
		return configurationEnumerator.get(clusterName);
	}

	public ResultSetClientFactory getResultSetClientFactory() {
		return resultSetClientFactory;
	}

	@Required
	public void setResultSetClientFactory(ResultSetClientFactory resultSetClientFactory) {
		this.resultSetClientFactory = resultSetClientFactory;
	}	
	
}

==> dnet-hadoop-service-1.0.7-20141111.100401-8-sources.jar: eu/dnetlib/data/hadoop/action/SequenceFileFeeder.java <==
package eu.dnetlib.data.hadoop.action;

import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.SequenceFile;
import org.apache.hadoop.io.Text;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Required;

import eu.dnetlib.data.hadoop.config.ClusterName;
import eu.dnetlib.data.hadoop.config.ConfigurationEnumerator;
import eu.dnetlib.data.hadoop.hdfs.SequenceFileWriterFactory;
import eu.dnetlib.enabling.resultset.client.ResultSetClientFactory;

public class SequenceFileFeeder {
	
	private static final Log log = LogFactory.getLog(SequenceFileFeeder.class); // NOPMD by marko on 11/24/08 5:02 PM
	
	private ResultSetClientFactory resultSetClientFactory;
	
	@Autowired
	protected ConfigurationEnumerator configurationEnumerator;
	
	@Autowired
	protected SequenceFileWriterFactory sequenceFileWriterFactory;
	
	public void feed(final String epr, final ClusterName clusterName, final String path, final ImportEprActionCallback callback) {
	
		final Thread feederThread = new Thread(new Runnable() {
			
			@Override
			public void run() {
				try {
					callback.done(doWrite(epr, clusterName, path));
				} catch (Throwable e) {
					callback.failed(e);
				}
			}

			private int doWrite(final String epr, final ClusterName clusterName, final String path) throws IOException {
				final SequenceFile.Writer writer = sequenceFileWriterFactory.getSequenceFileWriter(Text.class, Text.class, getConf(clusterName), new Path(path));
				
				final Text idText = new Text();
				final Text bodyText = new Text();
				
				int count = 0;
				
				for (String record : getResultSetClientFactory().getClient(epr)) {
					idText.set(String.valueOf(count++));
					bodyText.set(record);
					writer.append(idText, bodyText);
				}
				writer.close();

				log.info("written " + count + " records in sequence file: " + path);
				return count;
			}	
		});
		
		feederThread.start();
	}

	protected Configuration getConf(ClusterName clusterName) {
		return configurationEnumerator.get(clusterName);
	}

	public ResultSetClientFactory getResultSetClientFactory() {
		return resultSetClientFactory;
	}

	@Required
	public void setResultSetClientFactory(ResultSetClientFactory resultSetClientFactory) {
		this.resultSetClientFactory = resultSetClientFactory;
	}	
	
}
